@@ -1,3 +1,4 @@
+#define _GNU_SOURCE
 #include <stdio.h>
 #include <errno.h>
 #include <assert.h>
@@ -10,16 +11,12 @@
 
 #include <libaio.h>
 
-/* /dev/andrea */
-#define __KERNEL__
-#include <asm/page.h>
-#undef __KERNEL__
-/*
- * The below doesn't make sense in some arch with shared
- * address space betwene kernel and userspace but it'll
- * probably work by luck there too.
- */
-#define KERNEL_RW_POINTER       ((void *)PAGE_OFFSET)
+#if defined(__i386__)
+#define KERNEL_RW_POINTER	((void *)0xc0010000)
+#else
+//#warning Not really sure where kernel memory is.  Guessing.
+#define KERNEL_RW_POINTER	((void *)0xffffffffc0010000)
+#endif
 
 
 char test_name[] = TEST_NAME;
